.. _cli-show-version:

=======================
``toasty show version``
=======================

The ``show version`` command prints out the current version of the Toasty
software package.

.. _DOI: https://help.zenodo.org/

Usage
=====

.. code-block:: shell

   toasty show version

Prints out the current version of Toasty.

Notes
=====

In academic contexts, you may also wish to use the :ref:`cli-show-version-doi`
command to obtain a `DOI`_ that can be used to properly cite your use of the
Toasty software.

.. _DOI: https://help.zenodo.org/


See Also
========

- :ref:`cli-show-version-doi`
